==> haskell-hxt-regex-xmlschema-9.2.0.7-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-regex-xmlschema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hxt-regex-xmlschema
version:              9.2.0.7
visibility:           public
id:                   hxt-regex-xmlschema-9.2.0.7-BL3EMkzFHXOEH6WozBRAFJ
key:                  hxt-regex-xmlschema-9.2.0.7-BL3EMkzFHXOEH6WozBRAFJ
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            stable
homepage:
    http://www.haskell.org/haskellwiki/Regular_expressions_for_XML_Schema

synopsis:
    A regular expression library for W3C XML Schema regular expressions

description:
    This library supports full W3C XML Schema regular expressions
    inclusive all Unicode character sets and blocks.
    The complete grammar can be found under <http://www.w3.org/TR/xmlschema11-2/#regexs>.
    It is implemented by the technique of derivations of regular expressions.

    The W3C syntax is extended to support not only union of regular sets,
    but also intersection, set difference, exor.
    Matching of subexpressions is also supported.

    The library can be used for constricting lightweight scanners and tokenizers.
    It is a standalone library, no external regex libraries are used.

    Extensions in 9.2: The library does nor only support String'\''s, but also
    ByteString'\''s and Text in strict and lazy variants

category:             Text
abi:                  b9badee526aef74df452ca633c093a13
exposed:              True
exposed-modules:
    Text.Regex.Glob.Generic Text.Regex.Glob.Generic.RegexParser
    Text.Regex.Glob.String Text.Regex.XMLSchema.Generic
    Text.Regex.XMLSchema.Generic.Matching
    Text.Regex.XMLSchema.Generic.Regex
    Text.Regex.XMLSchema.Generic.RegexParser
    Text.Regex.XMLSchema.Generic.StringLike Text.Regex.XMLSchema.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hxt-regex-xmlschema-9.2.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hxt-regex-xmlschema-9.2.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hxt-regex-xmlschema-9.2.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hxt-regex-xmlschema
hs-libraries:         HShxt-regex-xmlschema-9.2.0.7-BL3EMkzFHXOEH6WozBRAFJ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hxt-charproperties-9.5.0.0-JsuB8BVB3oQCkNkgJgjWcz parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hxt-regex-xmlschema/html/hxt-regex-xmlschema.haddock

haddock-html:         /usr/share/doc/haskell-hxt-regex-xmlschema/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-regex-xmlschema-9.2.0.7-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-regex-xmlschema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hxt-regex-xmlschema
version:              9.2.0.7
visibility:           public
id:                   hxt-regex-xmlschema-9.2.0.7-Jq6LhMNS2V0GjCjCTiLoRF
key:                  hxt-regex-xmlschema-9.2.0.7-Jq6LhMNS2V0GjCjCTiLoRF
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            stable
homepage:
    http://www.haskell.org/haskellwiki/Regular_expressions_for_XML_Schema

synopsis:
    A regular expression library for W3C XML Schema regular expressions

description:
    This library supports full W3C XML Schema regular expressions
    inclusive all Unicode character sets and blocks.
    The complete grammar can be found under <http://www.w3.org/TR/xmlschema11-2/#regexs>.
    It is implemented by the technique of derivations of regular expressions.

    The W3C syntax is extended to support not only union of regular sets,
    but also intersection, set difference, exor.
    Matching of subexpressions is also supported.

    The library can be used for constricting lightweight scanners and tokenizers.
    It is a standalone library, no external regex libraries are used.

    Extensions in 9.2: The library does nor only support String'\''s, but also
    ByteString'\''s and Text in strict and lazy variants

category:             Text
abi:                  0f31295354e9f5dd2c22c67be5753b86
exposed:              True
exposed-modules:
    Text.Regex.Glob.Generic Text.Regex.Glob.Generic.RegexParser
    Text.Regex.Glob.String Text.Regex.XMLSchema.Generic
    Text.Regex.XMLSchema.Generic.Matching
    Text.Regex.XMLSchema.Generic.Regex
    Text.Regex.XMLSchema.Generic.RegexParser
    Text.Regex.XMLSchema.Generic.StringLike Text.Regex.XMLSchema.String

import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/hxt-regex-xmlschema-9.2.0.7

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/hxt-regex-xmlschema-9.2.0.7

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/hxt-regex-xmlschema-9.2.0.7

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hxt-regex-xmlschema
hs-libraries:         HShxt-regex-xmlschema-9.2.0.7-Jq6LhMNS2V0GjCjCTiLoRF
depends:
    base-4.18.3.0 bytestring-0.11.5.4
    hxt-charproperties-9.5.0.0-FMthv4ZwDIfCEoqIwVzqSZ parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hxt-regex-xmlschema/html/hxt-regex-xmlschema.haddock

haddock-html:         /usr/share/doc/haskell-hxt-regex-xmlschema/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
